Module chainparser::json
source · Structs
- Setup to deserialize accounts for a given program. The accounts are expected to have been serialized using the borsh format.
- This is the common way of resolving the account type for account data. It expects the first 8 bytes of data to hold the account discriminator as is the case for anchor accounts. This is what is used for Anchor accounts.